/*
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2010 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Melanie Rhianna Lewis <cyberspice@php.net>                   |
   +----------------------------------------------------------------------+
 */

#ifndef PHP_FRAMEGRAB_DEVICE_H_
#define PHP_FRAMEGRAB_DEVICE_H_

/**
 * Structure that contains information about a video capture device.
 */
typedef struct _php_framegrab_device_data {
	char *device;
	char *driver_name;
	char *card;
	int def_left;
	int def_top;
	int def_width;
	int def_height;
} php_framegrab_device_data;

/**
 * Structure that represents a node in the capture device list.
 */
typedef struct _php_framegrab_device_node {
	struct _php_framegrab_device_node *next;
	php_framegrab_device_data data;
} php_framegrab_device_node;

/**
 * Structure that represents a list of capture devices.
 */
typedef struct _php_framegrab_device_list {
	struct _php_framegrab_device_node *first;
	int count;
} php_framegrab_device_list;

/**
 * Initialises a php_framegrab_device_data structure.
 */
void php_framegrab_device_data_init(php_framegrab_device_data *data);

/**
 * Initialises a php_framegrab_device_data structure with the specified
 * values.
 */
int php_framegrab_device_data_init_ex(php_framegrab_device_data *data,
		                              int left, int top, int width, int height,
		                              char *device, char *driver_name, char *card);

/**
 * Destroys a php_framegrab_device_data structure freeing any memory
 * it is using.
 */
void php_framegrab_device_data_destroy(php_framegrab_device_data *data);

/**
 * Clones a php_framegrab_device_data structure.
 */
int php_framegrab_device_data_clone(php_framegrab_device_data *data,
		                            php_framegrab_device_data *copydata);

/**
 * Returns the device data for the specified video device.
 */
int php_framegrab_get_device_data(php_framegrab_device_data *data, char *device);

/**
 * Returns a character string describing the device.
 */
char *php_framegrab_device_data_to_string(php_framegrab_device_data *data);

#endif /* PHP_FRAMEGRAB_DEVICE_H_ */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * indent-tabs-mode: t
 * End:
 */
